MeshGradient class

A Figma mesh-gradient background. Changing preset cross-fades over crossDuration; when animateAmbient is true the mesh keeps gently undulating even while idle.

Figma 메시 배경. preset을 바꾸면 crossDuration 동안 크로스페이드된다. animateAmbient면 가만히 있어도 메시가 천천히 일렁인다.

Inheritance

Constructors

MeshGradient({Key? key, required MeshPreset preset, Duration crossDuration = const Duration(milliseconds: 1100), Curve curve = Curves.easeInOut, bool animateAmbient = true, double driftAmount = 1.0, Duration driftPeriod = const Duration(seconds: 18), Widget? child})
const

Properties

animateAmbient bool
final
child Widget?
final
crossDuration Duration
final
curve Curve
final
driftAmount double
Ambient drift strength (0 = still, 1 = default).
final
driftPeriod Duration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
preset MeshPreset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MeshGradient>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited