MeshPreset class

A single background frame (f_01f_04).

하나의 배경 프레임(f_01 ~ f_04).

Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewBox Size
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const List<MeshPreset>
f01 → const MeshPreset
f02 → const MeshPreset
f03 → const MeshPreset
f04 → const MeshPreset